#[repr(u8)]pub enum IntSource {
FILTER_INT = 0,
RAW_INT = 1,
}Variants
FILTER_INT = 0
Select Analog Comparator filtered output as input for interrupt detection.
RAW_INT = 1
Select Analog Comparator raw output (unfiltered) as input for interrupt detection. Must be used when Analog comparator is used as wake up source in Power down mode.
Implementations